.. image:: https://travis-ci.org/striglia/pyramid_swagger.png?branch=master
  :target: https://travis-ci.org/striglia/pyramid_swagger?branch=master

.. image:: https://coveralls.io/repos/striglia/pyramid_swagger/badge.png
  :target: https://coveralls.io/r/striglia/pyramid_swagger

.. image:: https://landscape.io/github/striglia/pyramid_swagger/master/landscape.png
   :target: https://landscape.io/github/striglia/pyramid_swagger/master

.. image:: https://pypip.in/py_versions/pyramid_swagger/badge.png
    :target: https://pypi.python.org/pypi/pyramid_swagger/
    :alt: Supported Python versions


pyramid_swagger
===============

This project offers convenient tools for using Swagger to define and validate
your interfaces in a Pyramid webapp.

Full documentation is available at http://pyramid-swagger.readthedocs.org/.

Copyright
---------

Copyright © 2014 Scott Triglia. `License BSD 3-clause
<http://opensource.org/licenses/BSD-3-Clause>`_.

This is free software: you are free to change and redistribute it. There is
NO WARRANTY, to the extent permitted by law.
